==> xlr-server-sql-23.1.12-sources.jar: com/xebialabs/xlrelease/repository/sql/persistence/data/ReleaseRow.scala <==
package com.xebialabs.xlrelease.repository.sql.persistence.data

import java.util.Date

case class ReleaseRow(json: String,
                      releaseId: String,
                      ciUid: Int,
                      folderId: String,
                      securityUid: Int,
                      status: String,
                      realFlagStatus: Int,
                      title: String,
                      startDate: Date,
                      endDate: Date,
                      riskScore: Int,
                      totalRiskScore: Int,
                      scmDataUid: Int,
                      plannedDuration: Integer,
                      isOverdueNotified: Boolean
                     )


case class BasicReleaseRow(releaseId: String,
                           ciUid: Int,
                           folderId: String,
                           securityUid: Int,
                           status: String,
                           realFlagStatus: Int,
                           title: String,
                           startDate: Date,
                           endDate: Date,
                           riskScore: Int,
                           totalRiskScore: Int,
                           scmDataUid: Int,
                           plannedDuration: Integer,
                           isOverdueNotified: Boolean
                          )

case class OriginTemplateDataRow(originTemplateId: String,
                                 originTemplateTitle: String
                                )

==> xlr-server-sql-23.3.0-721.113-sources.jar: com/xebialabs/xlrelease/repository/sql/persistence/data/ReleaseRow.scala <==
package com.xebialabs.xlrelease.repository.sql.persistence.data

import java.util.Date

case class ReleaseRow(json: String,
                      releaseId: String,
                      ciUid: Int,
                      folderId: String,
                      securityUid: Int,
                      status: String,
                      realFlagStatus: Int,
                      title: String,
                      startDate: Date,
                      endDate: Date,
                      riskScore: Int,
                      totalRiskScore: Int,
                      scmDataUid: Int,
                      plannedDuration: Integer,
                      isOverdueNotified: Boolean,
                      kind: String
                     )


case class BasicReleaseRow(releaseId: String,
                           ciUid: Int,
                           folderId: String,
                           securityUid: Int,
                           status: String,
                           realFlagStatus: Int,
                           title: String,
                           startDate: Date,
                           endDate: Date,
                           riskScore: Int,
                           totalRiskScore: Int,
                           scmDataUid: Int,
                           plannedDuration: Integer,
                           isOverdueNotified: Boolean,
                           kind: String
                          )

case class OriginTemplateDataRow(originTemplateId: String,
                                 originTemplateTitle: String
                                )
